@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -22,11 +22,14 @@
 #include <qlayout.h>
 #include <qheader.h>
 
+#include "libchmfile.h"
+
 #include "kchmmainwindow.h"
 #include "kchmindexwindow.h"
 #include "kchmlistitemtooltip.h"
-#include "xchmfile.h"
+#include "kchmtreeviewitem.h"
 
+#include "kchmindexwindow.moc"
 
 KCHMIndexWindow::KCHMIndexWindow ( QWidget * parent, const char * name, WFlags f )
 	: QWidget (parent, name, f)
@@ -42,6 +45,7 @@ KCHMIndexWindow::KCHMIndexWindow ( QWidget * parent, const char * name, WFlags f
 	m_indexList->header()->hide();
 	m_indexList->setTreeStepSize (10);
 	m_indexList->setShowToolTips(true);
+	//m_indexList->setSorting( 0, true );
 
 	layout->addWidget (m_indexFinder);
 	layout->addSpacing (10);
@@ -87,14 +91,11 @@ void KCHMIndexWindow::onTextChanged ( const QString & newvalue)
 
 void KCHMIndexWindow::showEvent( QShowEvent * )
 {
-	if ( !::mainWindow->getChmFile() || m_indexListFilled )
+	if ( !::mainWindow->chmFile() || m_indexListFilled )
 		return;
 
 	m_indexListFilled = true;
-	::mainWindow->getChmFile()->ParseAndFillIndex (m_indexList);
-	
-	if ( m_indexList->childCount() == 0 )
-		qWarning ("CHM index present but is empty; wrong parsing?");
+	refillIndex();
 }
 
 void KCHMIndexWindow::onReturnPressed( )
@@ -114,7 +115,7 @@ void KCHMIndexWindow::onDoubleClicked( QListViewItem *item, const QPoint &, int
 	if ( !item )
 		return;
 	
-	KCHMMainTreeViewItem * treeitem = (KCHMMainTreeViewItem*) item;
+	KCHMIndTocItem * treeitem = (KCHMIndTocItem*) item;
 	
 	QString url = treeitem->getUrl();
 	
@@ -137,15 +138,42 @@ void KCHMIndexWindow::onDoubleClicked( QListViewItem *item, const QPoint &, int
 void KCHMIndexWindow::slotContextMenuRequested( QListViewItem * item, const QPoint & point, int )
 {
 	if ( !m_contextMenu )
-		m_contextMenu = ::mainWindow->getCurrentBrowser()->createListItemContextMenu( this );
+		m_contextMenu = ::mainWindow->currentBrowser()->createListItemContextMenu( this );
 		
 	if( item )
 	{
-		KCHMMainTreeViewItem * treeitem = (KCHMMainTreeViewItem*) item;
+		KCHMIndTocItem * treeitem = (KCHMIndTocItem*) item;
 		
-		::mainWindow->getCurrentBrowser()->setTabKeeper( treeitem->getUrl() );
+		::mainWindow->currentBrowser()->setTabKeeper( treeitem->getUrl() );
 		m_contextMenu->popup( point );
 	}
 }
 
-#include "kchmindexwindow.moc"
+void KCHMIndexWindow::refillIndex( )
+{
+	QValueVector< LCHMParsedEntry > data;
+	
+	if ( !::mainWindow->chmFile()->parseIndex( &data )
+			   || data.size() == 0 )
+	{
+		qWarning ("CHM index present but is empty; wrong parsing?");
+		return;
+	}
+	
+	kchmFillListViewWithParsedData( m_indexList, data, 0 );
+}
+
+void KCHMIndexWindow::search( const QString & index )
+{
+	if ( !::mainWindow->chmFile() )
+		return;
+
+	if ( !m_indexListFilled )
+	{
+		m_indexListFilled = true;
+		refillIndex();
+	}
+
+	m_indexFinder->setText( index );
+	onTextChanged( index );
+}
