@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -18,6 +18,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
+
 #ifndef KCHMINDEXWINDOW_H
 #define KCHMINDEXWINDOW_H
 
@@ -31,28 +32,31 @@
 */
 class KCHMIndexWindow : public QWidget
 {
-Q_OBJECT
-public:
-    KCHMIndexWindow ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
-
-	void	invalidate();
+	Q_OBJECT
+	public:
+		KCHMIndexWindow ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
 	
-public slots:
-	void	slotContextMenuRequested ( QListViewItem *item, const QPoint &point, int column );
+		void	invalidate();
+		void	search( const QString& index );
 		
-private slots:
-	void 	onTextChanged ( const QString & newvalue);
-	void 	onReturnPressed ();
-	void	onDoubleClicked ( QListViewItem *, const QPoint &, int);
-
-private:
-	virtual void showEvent ( QShowEvent * );
+	public slots:
+		void	slotContextMenuRequested ( QListViewItem *item, const QPoint &point, int column );
+			
+	private slots:
+		void 	onTextChanged ( const QString & newvalue);
+		void 	onReturnPressed ();
+		void	onDoubleClicked ( QListViewItem *, const QPoint &, int);
 	
-	QLineEdit 	*	m_indexFinder;
-	KQListView	*	m_indexList;
-	KQPopupMenu * 	m_contextMenu;	
-	QListViewItem * m_lastSelectedItem;
-	bool			m_indexListFilled;
+	private:
+		virtual void showEvent ( QShowEvent * );
+		
+		void	refillIndex();
+		
+		QLineEdit 	*	m_indexFinder;
+		KQListView	*	m_indexList;
+		KQPopupMenu * 	m_contextMenu;	
+		QListViewItem * m_lastSelectedItem;
+		bool			m_indexListFilled;
 };
 
 #endif
