@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -29,6 +29,11 @@
 #include "kde-qt.h"
 
 #include <qaccel.h>
+#include <qevent.h>
+
+#include "libchmfile.h"
+#include "libchmfileimpl.h"
+#include "libchmurlfactory.h"
 
 #include "kchmmainwindow.h"
 #include "kchmconfig.h"
@@ -46,11 +51,12 @@
 #include "kchmkeyeventfilter.h"
 #include "kchmcontentswindow.h"
 
-
 #if !defined (USE_KDE)
 	#include "kqrunprocess.h"
 #endif
 
+#include "kchmmainwindow.moc"
+
 
 KCHMMainWindow::KCHMMainWindow()
     : KQMainWindow ( 0, "KCHMMainWindow", WDestructiveClose )
@@ -112,6 +118,13 @@ KCHMMainWindow::KCHMMainWindow()
 
 	statusBar()->show();
 	setIcon( *gIconStorage.getApplicationIcon() );
+
+	m_aboutDlgMenuText = i18n( "%1 version %2\n\nCopyright (C) George Yunaev,"
+			"gyunaev@ulduzsoft.com, 2004-2007\nhttp://www.kchmviewer.net\n\n"
+			"Licensed under GNU GPL license.\n\n"
+			"Please check my another project, http://www.transientmail.com - temporary "
+			"e-mail address, which expires automatically." )
+			. arg(APP_NAME) . arg(APP_VERSION);
 }
 
 
@@ -142,10 +155,11 @@ void KCHMMainWindow::slotOpenMenuItemActivated()
 
 bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page )
 {
-	CHMFile * new_chmfile = new CHMFile (fileName);
+	LCHMFile * new_chmfile = new LCHMFile();
 	
-	if ( new_chmfile->IsOk() )
+	if ( new_chmfile->loadFile( fileName ) )
 	{
+		// The new file is opened, so we can close the old one
 		if ( m_chmFile )
 		{
 			closeChmFile( );
@@ -153,7 +167,11 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 		}
 	
 		m_chmFile = new_chmfile;
+		
+		// Show current encoding in status bar
+		showInStatusBar( tr("Detected chm file charset: %1") . arg(m_chmFile->currentEncoding()->language) );
 
+		// Make the file name absolute; we'll need it later
 		QDir qd;
 		qd.setPath (fileName);
 		m_chmFilename = qd.absPath();
@@ -165,20 +183,18 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 		// Order the tabulations
 		int number_of_pages = 0;
 		
-		if ( m_chmFile->TopicsFile() )
+		if ( m_chmFile->hasTableOfContents() )
 			m_tabContextPage = number_of_pages++;
 		else
 			m_tabContextPage = -1;
 
-		if ( m_chmFile->IndexFile() )
+		if ( m_chmFile->hasIndexTable() )
 			m_tabIndexPage = number_of_pages++;
 		else
 			m_tabIndexPage = -1;
 
-		if ( m_chmFile->isSearchAvailable() )
-			m_tabSearchPage = number_of_pages++;
-		else
-			m_tabSearchPage = -1;
+		// We always show search
+		m_tabSearchPage = number_of_pages++;
 
 		m_tabBookmarkPage = number_of_pages;
 
@@ -193,14 +209,15 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 
 		if ( m_currentSettings->loadSettings (fileName) )
 		{
-			const KCHMTextEncoding::text_encoding_t * enc = KCHMTextEncoding::lookupByLCID (m_currentSettings->m_activeencodinglcid);
+			const LCHMTextEncoding * encoding = 
+					m_chmFile->impl()->lookupByLCID(  m_currentSettings->m_activeencodinglcid );
 
 			m_tabWidget->setCurrentPage( m_currentSettings->m_activetabsystem );
 			
-			if ( enc )
+			if ( encoding )
 			{
-				m_chmFile->setCurrentEncoding (enc);
-				m_searchToolbar->setChosenEncodingInMenu (enc);
+				m_chmFile->setCurrentEncoding( encoding );
+				m_searchToolbar->setChosenEncodingInMenu( encoding );
 			}
 			
 			if ( m_searchWindow )
@@ -225,10 +242,10 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 		else
 		{
 			m_tabWidget->setCurrentPage (0);
-			m_searchToolbar->setChosenEncodingInMenu (m_chmFile->getCurrentEncoding());
+			m_searchToolbar->setChosenEncodingInMenu( m_chmFile->currentEncoding() );
 			
 			if ( call_open_page )
-				openPage( m_chmFile->HomePage() );
+				openPage( m_chmFile->homeUrl() );
 		}
 
 		m_searchToolbar->setEnabled (true);
@@ -238,18 +255,14 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 	}
 	else
 	{
-		if ( !m_chmFile )
-		{
-			QMessageBox mbox(
-					i18n("%1 - failed to load the chm file") . arg(APP_NAME),
-					i18n("Unable to load the chm file %1") . arg(fileName), 
-					QMessageBox::Critical, 
-					QMessageBox::Ok, 
-					QMessageBox::NoButton, 
-					QMessageBox::NoButton);
-			mbox.exec();
-			exit (1);
-		}
+		QMessageBox mbox(
+				i18n("%1 - failed to load the chm file") . arg(APP_NAME),
+				i18n("Unable to load the chm file %1") . arg(fileName), 
+				QMessageBox::Critical, 
+				QMessageBox::Ok, 
+				QMessageBox::NoButton, 
+				QMessageBox::NoButton);
+		mbox.exec();
 		
 		statusBar()->message( 
 				i18n("Could not load file %1").arg(fileName),
@@ -262,19 +275,14 @@ bool KCHMMainWindow::loadChmFile ( const QString &fileName, bool call_open_page
 
 void KCHMMainWindow::slotPrintMenuItemActivated()
 {
-	getCurrentBrowser()->printCurrentPage();
+	currentBrowser()->printCurrentPage();
 }
 
 
 void KCHMMainWindow::slotAboutMenuItemActivated()
 {
 	QString caption = i18n( "About %1" ) . arg(APP_NAME);
-	QString text = i18n( "%1 version %2\n\nCopyright (C) George Yunaev,"
-		"gyunaev@ulduzsoft.com, 2005-2006\nwww.kchmviewer.net\n\n"
-		"Licensed under GNU GPL license.\n\n"
-		"Please try our another project, www.transientmail.com - temporary "
-		"e-mail address, which expires automatically." )
-			. arg(APP_NAME) . arg(APP_VERSION);
+	QString text = m_aboutDlgMenuText;
 	
 	// It is quite funny that the argument order differs
 #if defined (USE_KDE)
@@ -292,21 +300,22 @@ void KCHMMainWindow::slotAboutQtMenuItemActivated()
 
 void KCHMMainWindow::refreshCurrentBrowser( )
 {
-	QString title = m_chmFile->Title();
+	QString title = m_chmFile->title();
+	
 	if ( !title )
 		title = APP_NAME;
+	// KDE adds application name automatically, so we don't need it here	
+#if !defined (USE_KDE)
 	else
 		title = (QString) APP_NAME + " - " + title;
+#endif	
+	
 	setCaption ( title );
 	
-	getCurrentBrowser()->invalidate();
+	currentBrowser()->invalidate();
 	
 	if ( m_contentsWindow )
-	{
-		m_contentsWindow->clear();
-		m_chmFile->ParseAndFillTopicsTree(m_contentsWindow);
-		m_contentsWindow->triggerUpdate();
-	}
+		m_contentsWindow->refillTableOfContents();
 }
 
 void KCHMMainWindow::slotOnTreeClicked( QListViewItem * item )
@@ -316,7 +325,7 @@ void KCHMMainWindow::slotOnTreeClicked( QListViewItem * item )
 	if ( !item )
 		return;
 	
-	KCHMMainTreeViewItem * treeitem = (KCHMMainTreeViewItem*) item;
+	KCHMIndTocItem * treeitem = (KCHMIndTocItem*) item;
 	slotLinkClicked( treeitem->getUrl(), unused );
 }
 
@@ -345,8 +354,11 @@ void KCHMMainWindow::slotLinkClicked ( const QString & link, bool& follow_link )
 bool KCHMMainWindow::openPage( const QString & srcurl, unsigned int flags )
 {
 	QString p1, p2, url = srcurl;
+	
+	if ( url == "/" )
+		url = m_chmFile->homeUrl();
 
-	if ( getCurrentBrowser()->isRemoteURL (url, p1) )
+	if ( LCHMUrlFactory::isRemoteURL (url, p1) )
 	{
 		switch ( appConfig.m_onExternalLinkClick )
 		{
@@ -378,7 +390,7 @@ bool KCHMMainWindow::openPage( const QString & srcurl, unsigned int flags )
 	}
 		
 	// Filter the URLs which do not need to be opened at all by Qt version
-	if ( getCurrentBrowser()->isJavascriptURL (url) )
+	if ( LCHMUrlFactory::isJavascriptURL (url) )
 	{
 		QMessageBox::information( this, 
 			i18n( "%1 - JavsScript link clicked") . arg(APP_NAME),
@@ -387,8 +399,7 @@ bool KCHMMainWindow::openPage( const QString & srcurl, unsigned int flags )
 		return false;
 	}
 
-	if ( getCurrentBrowser()->isNewChmURL (url, p1, p2) 
-	&& p1 != m_chmFilename )
+	if ( LCHMUrlFactory::isNewChmURL (url, p1, p2) && p1 != m_chmFilename )
 	{
    		if ( QMessageBox::question( this,
 			i18n( "%1 - link to a new CHM file clicked"). arg(APP_NAME),
@@ -400,20 +411,23 @@ bool KCHMMainWindow::openPage( const QString & srcurl, unsigned int flags )
 		// Because chm file always contain relative link, and current filename is not changed,
 		// we need to form a new path
 		QFileInfo qfi( m_chmFilename );
-
-		if ( !loadChmFile ( qfi.dirPath(true) + "/" + p1, false ) )
-			return false;
-
-		url = p2;
+		QString newfilename = qfi.dirPath(true) + "/" + p1;
+		
+		QStringList event_args;
+		event_args.push_back( newfilename );
+		event_args.push_back( p2 ); // url
+		
+		qApp->postEvent( this, new KCHMUserEvent( "loadAndOpen", event_args ) );
+		return false;
 	}
 	
-	KCHMViewWindow * vwnd = getCurrentBrowser();
+	KCHMViewWindow * vwnd = currentBrowser();
 	if ( flags & OPF_NEW_TAB )
 		vwnd = m_viewWindowMgr->addNewTab( !(flags & OPF_BACKGROUND) );
 	
 	// Store current page and position to add it to history if we change it
-	int hist_scrollpos = getCurrentBrowser()->getScrollbarPosition();
-	QString hist_url = getCurrentBrowser()->getOpenedPage();
+	int hist_scrollpos = currentBrowser()->getScrollbarPosition();
+	QString hist_url = currentBrowser()->getOpenedPage();
 	
 	if ( vwnd->openUrl (url) )
 	{
@@ -422,7 +436,7 @@ bool KCHMMainWindow::openPage( const QString & srcurl, unsigned int flags )
 			locateInContentTree( vwnd->getOpenedPage() );
 		
 		if ( flags & OPF_ADD2HISTORY )
-			getCurrentBrowser()->addNavigationHistory( hist_url, hist_scrollpos );
+			currentBrowser()->addNavigationHistory( hist_url, hist_scrollpos );
 	}
 	
 	return true;
@@ -525,14 +539,17 @@ void KCHMMainWindow::setupToolbarsAndMenu( )
 	menuBar()->insertItem( i18n( "&Settings"), settings );
 	settings->insertItem( i18n( "&Change settings..."), this, SLOT( slotChangeSettingsMenuItemActivated() ));
 
+#if defined(USE_KDE)
+	QPopupMenu *help = helpMenu( m_aboutDlgMenuText );
+#else
     KQPopupMenu * help = new KQPopupMenu( this );
-	menuBar()->insertItem( i18n( "&Help"), help );
-
 	help->insertItem( i18n( "&About"), this, SLOT( slotAboutMenuItemActivated() ), Key_F1 );
 	help->insertItem( i18n( "About &Qt"), this, SLOT( slotAboutQtMenuItemActivated() ));
-    help->insertSeparator();
+	help->insertSeparator();
 	help->insertItem( i18n( "What's &This"), this, SLOT(whatsThis()), SHIFT+Key_F1 );
-	
+#endif
+		
+	menuBar()->insertItem( i18n( "&Help"), help );
 	updateHistoryMenu();
 }
 
@@ -541,19 +558,19 @@ void KCHMMainWindow::slotAddBookmark( )
 	emit m_bookmarkWindow->onAddBookmarkPressed ();
 }
 
-void KCHMMainWindow::setTextEncoding( const KCHMTextEncoding::text_encoding_t * enc )
+void KCHMMainWindow::setTextEncoding( const LCHMTextEncoding * encoding )
 {
-	m_chmFile->setCurrentEncoding (enc);
-	m_searchToolbar->setChosenEncodingInMenu (enc);
+	m_chmFile->setCurrentEncoding( encoding );
+	m_searchToolbar->setChosenEncodingInMenu( encoding );
 	
 	// Because updateView() will call view->invalidate(), which clears the view->getOpenedPage(),
 	// we have to make a copy of it.
-	QString url = getCurrentBrowser()->getOpenedPage();
+	QString url = currentBrowser()->getOpenedPage();
+	
+	// Regenerate the content and index trees	
 	refreshCurrentBrowser();
 	
-	// Regenerate the content and index trees
-	
-	getCurrentBrowser()->openUrl ( url );
+	currentBrowser()->openUrl( url );
 }
 
 void KCHMMainWindow::closeChmFile( )
@@ -561,7 +578,7 @@ void KCHMMainWindow::closeChmFile( )
 	// Prepare the settings
 	if ( appConfig.m_HistoryStoreExtra )
 	{
-		m_currentSettings->m_activeencodinglcid = m_chmFile->getCurrentEncoding()->winlcid;
+		m_currentSettings->m_activeencodinglcid = m_chmFile->currentEncoding()->winlcid;
 		m_currentSettings->m_activetabsystem = m_tabWidget->currentPageIndex( );
 		m_currentSettings->m_activetabwindow = m_viewWindowMgr->currentPageIndex( );
 		
@@ -587,7 +604,11 @@ void KCHMMainWindow::closeEvent ( QCloseEvent * e )
 {
 	// Save the settings if we have something opened
 	if ( m_chmFile )
+	{
 		closeChmFile( );
+		delete m_chmFile;
+		m_chmFile = 0;
+	}
 
 	QMainWindow::closeEvent ( e );
 }
@@ -606,11 +627,10 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 	
 	if ( args->isSet("shortautotestmode") )
 		do_autotest = m_useShortAutotest = true;
-/*
+
 	search_query = args->getOption ("search");
 	search_index = args->getOption ("sindex");
-	search_bookmark = args->getOption ("sbook");
-*/
+	
 	if ( args->count() > 0 )
 		filename = args->arg(0);
 #else
@@ -625,8 +645,6 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 			search_query = qApp->argv()[++i];
 		else if ( !strcmp (qApp->argv()[i], "--sindex") )
 			search_index = qApp->argv()[++i];
-		else if ( !strcmp (qApp->argv()[i], "--sbook") )
-			search_bookmark = qApp->argv()[++i];
 		else if ( !strcmp (qApp->argv()[i], "-h") || !strcmp (qApp->argv()[i], "--help") )
 		{
 			fprintf (stderr, "Usage: %s [chmfile]\n", qApp->argv()[0]);
@@ -640,15 +658,21 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 	if ( !filename.isEmpty() )
 	{
 		if ( !loadChmFile( QString::fromLocal8Bit( filename )) )
-			return false;
-/*
-		if ( search_index.isEmpty() )
-			
-			
-			search_query = args->getOption ("search");
+			return true; // skip the latest checks, but do not exit from the program
+
+		if ( !search_index.isEmpty() )
+		{
+			QStringList event_args;
+			event_args.push_back( search_index );
+			qApp->postEvent( this, new KCHMUserEvent( "findInIndex", event_args ) );
+		}
 		
-		search_bookmark = args->getOption ("sbook");
-*/
+		if ( !search_query.isEmpty() )	
+		{
+			QStringList event_args;
+			event_args.push_back( search_query );
+			qApp->postEvent( this, new KCHMUserEvent( "searchQuery", event_args ) );
+		}
 		
 		if ( do_autotest )
 		{
@@ -671,12 +695,12 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 
 void KCHMMainWindow::slotBrowserSelectAll( )
 {
-	getCurrentBrowser()->clipSelectAll();
+	currentBrowser()->clipSelectAll();
 }
 
 void KCHMMainWindow::slotBrowserCopy( )
 {
-	getCurrentBrowser()->clipCopy();
+	currentBrowser()->clipCopy();
 }
 
 void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
@@ -718,6 +742,14 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 	dlg.m_advViewSourceExternal->setChecked ( !appConfig.m_advUseInternalEditor );
 	dlg.m_advViewSourceInternal->setChecked ( appConfig.m_advUseInternalEditor );
 	
+	// Search engine
+	dlg.m_useSearchEngineInternal->setChecked( appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_CHM );
+	dlg.m_useSearchEngineNew->setChecked( appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_MINE );
+	
+	// Connect buddies
+	dlg.m_labelUseSearchEngineInternal->setBuddy( dlg.m_useSearchEngineInternal );
+	dlg.m_labelUseSearchEngineNew->setBuddy( dlg.m_useSearchEngineNew );
+	
 	if ( dlg.exec() == QDialog::Accepted )
 	{
 		appConfig.m_LoadLatestFileOnStartup = dlg.m_radioOnBeginOpenLast->isChecked();
@@ -773,6 +805,20 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 			appConfig.m_kdeUseQTextBrowser = dlg.m_radioUseQtextBrowser->isChecked();
 		}
 		
+		if ( dlg.m_useSearchEngineNew->isChecked() 
+		&& appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_CHM )
+		{
+			appConfig.m_useSearchEngine = KCHMConfig::SEARCH_USE_MINE;
+			m_searchWindow->invalidate();
+		}
+		
+		if ( dlg.m_useSearchEngineInternal->isChecked() 
+		&& appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_MINE )
+		{
+			appConfig.m_useSearchEngine = KCHMConfig::SEARCH_USE_CHM;
+			m_searchWindow->invalidate();
+		}
+					
 		appConfig.m_advExternalEditorPath = dlg.m_advExternalProgramName->text();
 		appConfig.m_advUseInternalEditor = dlg.m_advViewSourceExternal->isChecked();
 		appConfig.m_advUseInternalEditor = dlg.m_advViewSourceInternal->isChecked();
@@ -783,8 +829,8 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 			QMessageBox::information( 
 					this,
 					APP_NAME,
-					i18n( "Changing browser view options require\nrestarting the application to take effect." )
-									);
+					i18n( "Changing browser view options or search engine used\n"
+							"requires restarting the application to take effect." )	);
 	}
 }
 
@@ -975,24 +1021,29 @@ void KCHMMainWindow::slotLocateInContentWindow( )
 	// Activate a content tab
 	m_tabWidget->setCurrentPage( m_tabContextPage );
 	
-	// Open all the tree items to show current item (if needed)
-	KCHMMainTreeViewItem * treeitem = m_chmFile->getTreeItem( getCurrentBrowser()->getOpenedPage() );
-	if ( m_contentsWindow && treeitem )
+	if ( m_contentsWindow )
 	{
-		KCHMMainTreeViewItem * itemparent = treeitem;
-		while ( (itemparent = (KCHMMainTreeViewItem*) itemparent->parent()) != 0 )
-			itemparent->setOpen(true);
+		// Open all the tree items to show current item (if needed)
+		KCHMIndTocItem * treeitem = m_contentsWindow->getTreeItem( currentBrowser()->getOpenedPage() );
+	
+		if ( treeitem )
+		{
+			KCHMIndTocItem * itemparent = treeitem;
 			
-		m_contentsWindow->setCurrentItem (treeitem);
-		m_contentsWindow->ensureItemVisible (treeitem);
+			while ( (itemparent = (KCHMIndTocItem*) itemparent->parent()) != 0 )
+				itemparent->setOpen(true);
+			
+			m_contentsWindow->setCurrentItem (treeitem);
+			m_contentsWindow->ensureItemVisible (treeitem);
+		}
+		else
+			statusBar()->message( i18n( "Could not locate opened topic in content window"), 2000 );
 	}
-	else
-		statusBar()->message( i18n( "Could not locate opened topic in content window"), 2000 );
 }
 
 void KCHMMainWindow::slotExtractCHM( )
 {
-	QValueVector<QString> files;
+	QStringList files;
 	
 #if defined (USE_KDE)
 	QString outdir = KFileDialog::getExistingDirectory (
@@ -1014,7 +1065,7 @@ void KCHMMainWindow::slotExtractCHM( )
 	outdir += "/";
 	
 	// Enumerate all the files in archive
-	if ( !m_chmFile || !m_chmFile->enumerateArchive (files) )
+	if ( !m_chmFile || !m_chmFile->enumerateFiles( &files ) )
 		return;
 
 	KQProgressModalDialog progress( i18n("Extracting CHM content"), i18n("Extracting files..."), i18n("Abort"), files.size(), this );
@@ -1032,78 +1083,74 @@ void KCHMMainWindow::slotExtractCHM( )
 		}
 
 		// Extract the file
-		chmUnitInfo ui;	
-		if ( m_chmFile->ResolveObject( files[i], &ui ) )
+		QByteArray buf;
+		
+		if ( m_chmFile->getFileContentAsBinary( &buf, files[i] ) )
 		{
-			QByteArray buf( ui.length );
-			
-			if ( m_chmFile->RetrieveObject (&ui, (unsigned char*) buf.data(), 0, ui.length) )
-			{
-				// Split filename to get the list of subdirectories
-				QStringList dirs = QStringList::split( '/', files[i] );
+			// Split filename to get the list of subdirectories
+			QStringList dirs = QStringList::split( '/', files[i] );
 
-				// Walk through the list of subdirectories, and create them if needed
-				// dirlevel is used to detect extra .. and prevent overwriting files
-				// outside the directory (like creating the file images/../../../../../etc/passwd
-				unsigned int i, dirlevel = 0;
-				QStringList dirlist;
+			// Walk through the list of subdirectories, and create them if needed
+			// dirlevel is used to detect extra .. and prevent overwriting files
+			// outside the directory (like creating the file images/../../../../../etc/passwd
+			unsigned int i, dirlevel = 0;
+			QStringList dirlist;
 				
-				for ( i = 0; i < dirs.size() - 1; i++ )
+			for ( i = 0; i < dirs.size() - 1; i++ )
+			{
+				// Skip .. which lead too far above
+				if ( dirs[i] == ".." )
 				{
-					// Skip .. which lead too far above
-					if ( dirs[i] == ".." )
+					if ( dirlevel > 0 )
 					{
-						if ( dirlevel > 0 )
-						{
-							dirlevel--;
-							dirlist.pop_back();
-						}
-					}
-					else
-					{
-						dirlist.push_back( dirs[i] );
-						
-						QDir dir ( outdir + dirlist.join( "/" ) );
-						if ( !dir.exists() )
-						{
-							if ( !dir.mkdir( dir.path() ) )
-								qWarning( "Could not create subdir %s\n", dir.path().ascii() );
-						}
+						dirlevel--;
+						dirlist.pop_back();
 					}
 				}
-				
-				QString filename = outdir + dirlist.join( "/" ) + "/" + dirs[i];
-				QFile wf( filename );
-				if ( !wf.open( IO_WriteOnly ) )
+				else
 				{
-					 qWarning( "Could not write file %s\n", filename.ascii() );
-					 continue;
+					dirlist.push_back( dirs[i] );
+					
+					QDir dir ( outdir + dirlist.join( "/" ) );
+					if ( !dir.exists() )
+					{
+						if ( !dir.mkdir( dir.path() ) )
+							qWarning( "Could not create subdir %s\n", dir.path().ascii() );
+					}
 				}
-				
-				wf. writeBlock( buf );
-				wf.close();
 			}
+			
+			QString filename = outdir + dirlist.join( "/" ) + "/" + dirs[i];
+			QFile wf( filename );
+			if ( !wf.open( IO_WriteOnly ) )
+			{
+					qWarning( "Could not write file %s\n", filename.ascii() );
+					continue;
+			}
+			
+			wf. writeBlock( buf );
+			wf.close();
 		}
 		else
-			qWarning( "Could not resolve file %s\n", files[i].ascii() );
+			qWarning( "Could not get file %s\n", files[i].ascii() );
 	}
 	
 	progress.setProgress( files.size() );
 }
 
-KCHMViewWindow * KCHMMainWindow::getCurrentBrowser( ) const
+KCHMViewWindow * KCHMMainWindow::currentBrowser( ) const
 {
 	return m_viewWindowMgr->current();
 }
 
 void KCHMMainWindow::slotOpenPageInNewTab( )
 {
-	openPage( getCurrentBrowser()->getNewTabLink(), OPF_NEW_TAB | OPF_CONTENT_TREE );
+	openPage( currentBrowser()->getNewTabLink(), OPF_NEW_TAB | OPF_CONTENT_TREE );
 }
 
 void KCHMMainWindow::slotOpenPageInNewBackgroundTab( )
 {
-	openPage( getCurrentBrowser()->getNewTabLink(), OPF_NEW_TAB | OPF_BACKGROUND );
+	openPage( currentBrowser()->getNewTabLink(), OPF_NEW_TAB | OPF_BACKGROUND );
 }
 
 void KCHMMainWindow::slotBrowserChanged( KCHMViewWindow * newbrowser )
@@ -1113,12 +1160,15 @@ void KCHMMainWindow::slotBrowserChanged( KCHMViewWindow * newbrowser )
 
 void KCHMMainWindow::locateInContentTree( const QString & url )
 {
-	KCHMMainTreeViewItem * treeitem = m_chmFile->getTreeItem( url );
+	if ( !m_contentsWindow )
+		return;
 	
-	if ( treeitem && m_contentsWindow )
+	KCHMIndTocItem * treeitem = m_contentsWindow->getTreeItem( url );
+	
+	if ( treeitem )
 	{
-		KCHMMainTreeViewItem * itemparent = treeitem;
-		while ( (itemparent = (KCHMMainTreeViewItem*) itemparent->parent()) != 0 )
+		KCHMIndTocItem * itemparent = treeitem;
+		while ( (itemparent = (KCHMIndTocItem*) itemparent->parent()) != 0 )
 			itemparent->setOpen(true);
 			
 		m_contentsWindow->setCurrentItem (treeitem);
@@ -1136,11 +1186,68 @@ void KCHMMainWindow::slotOnTreeDoubleClicked( QListViewItem * item, const QPoint
 	item->repaint();
 }
 
+bool KCHMMainWindow::event( QEvent * e )
+{
+	if ( e->type() == QEvent::User )
+		return handleUserEvent( (KCHMUserEvent*) e );
+	
+	return QWidget::event( e );
+}
+
+bool KCHMMainWindow::handleUserEvent( const KCHMUserEvent * event )
+{
+	if ( event->m_action == "loadAndOpen" )
+	{
+		if ( event->m_args.size() != 1 && event->m_args.size() != 2 )
+			qFatal("handleUserEvent: event loadAndOpen must receive 1 or 2 args");
+		
+		QString chmfile = event->m_args[0];
+		QString openurl = event->m_args.size() > 1 ? event->m_args[1] : "/";
+				
+		return loadChmFile( chmfile, false ) && openPage( openurl );
+	}
+	else if ( event->m_action == "openPage" )
+	{
+		if ( event->m_args.size() != 1 )
+			qFatal("handleUserEvent: event openPage must receive 1 arg");
+		
+		return openPage( event->m_args[0] );
+	}
+	else if ( event->m_action == "findInIndex" )
+	{
+		if ( event->m_args.size() != 1 )
+			qFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
+		
+		if ( m_tabIndexPage == -1 )
+			return false;
+
+		slotActivateIndexTab();
+		m_indexWindow->search( event->m_args[0] );
+		return true;
+	}
+	else if ( event->m_action == "searchQuery" )
+	{
+		if ( event->m_args.size() != 1 )
+			qFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
+		
+		if ( m_tabSearchPage == -1 )
+			return false;
+
+		slotActivateSearchTab();
+		m_searchWindow->execSearchQueryInGui( event->m_args[0] );
+		return true;
+	}
+	else
+		qWarning( "Unknown user event received: %s", event->m_action.ascii() );
+	
+	return false;
+}
+
 
 #if defined (ENABLE_AUTOTEST_SUPPORT)
 void KCHMMainWindow::runAutoTest()
 {
-	KCHMMainTreeViewItem * item;
+	KCHMIndTocItem * item;
 
 	switch (m_autoteststate)
 	{
@@ -1157,7 +1264,7 @@ void KCHMMainWindow::runAutoTest()
 		break; // allow to finish the initialization sequence
 		
 	case STATE_CONTENTS_OPENNEXTPAGE:
-		if ( (item = (KCHMMainTreeViewItem *) m_autotestlistiterator.current()) != 0 )
+		if ( (item = (KCHMIndTocItem *) m_autotestlistiterator.current()) != 0 )
 		{
 			openPage( item->getUrl(), OPF_CONTENT_TREE | OPF_ADD2HISTORY );
 			m_autotestlistiterator++;
@@ -1187,4 +1294,5 @@ void KCHMMainWindow::runAutoTest()
 #endif /* defined (ENABLE_AUTOTEST_SUPPORT) */
 
 
-#include "kchmmainwindow.moc"
+//TODO: KDE: xmlgui
+//TODO: Search result highlighting
