@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -26,41 +26,60 @@
 
 #include "kchmsettings.h"
 #include "forwarddeclarations.h"
-#include "xchmfile.h"
 
 
 /**
 @author Georgy Yunaev
 */
+class KCHMSearchEngine;
+
+
+class KCHMClickableLabel : public QLabel
+{
+	Q_OBJECT
+	public:
+		KCHMClickableLabel( const QString& label, QWidget * parent )
+	: QLabel( label, parent ) {};
+		
+		virtual ~KCHMClickableLabel() {};
+				
+	signals:
+		void	clicked();
+						
+	protected:
+		virtual void mousePressEvent ( QMouseEvent * ) 	{ emit clicked(); }
+};
+
+
 class KCHMSearchWindow : public QWidget
 {
-Q_OBJECT
-public:
-    KCHMSearchWindow ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
-
-	void	invalidate();
-	void	restoreSettings (const KCHMSettings::search_saved_settings_t& settings);
-	void	saveSettings (KCHMSettings::search_saved_settings_t& settings);
-
-public slots:
-	void	slotContextMenuRequested ( QListViewItem *item, const QPoint &point, int column );
+	Q_OBJECT
+	public:
+		KCHMSearchWindow ( QWidget * parent = 0, const char * name = 0, WFlags f = 0 );
 	
-private slots:
-	void	onHelpClicked();
-	void 	onReturnPressed ();
-	void	onDoubleClicked ( QListViewItem *, const QPoint &, int);
-
-private:
-	bool	searchQuery ( QString query, KCHMSearchResults_t& results, unsigned int limit_results = 100 );
-	bool	searchWord ( const QString& word, KCHMSearchProgressResults_t & results );
-	bool	searchPhrase ( const QStringList& phrase, KCHMSearchProgressResults_t & results );
-
-	QString			m_lastQuery; // for 'Search in results' option
- 	QComboBox 	*	m_searchQuery;
-	KQListView	*	m_searchList;
-	QCheckBox	*	m_matchSimilarWords;
-	QPushButton *	m_helpButton;
-	KQPopupMenu * 	m_contextMenu;		
+		void	invalidate();
+		void	restoreSettings (const KCHMSettings::search_saved_settings_t& settings);
+		void	saveSettings (KCHMSettings::search_saved_settings_t& settings);
+		void	execSearchQueryInGui( const QString& query );
+		bool	searchQuery( const QString& query, QStringList * results );
+		
+	public slots:
+		void	slotContextMenuRequested ( QListViewItem *item, const QPoint &point, int column );
+		
+	private slots:
+		void	onHelpClicked();
+		void 	onReturnPressed ();
+		void	onDoubleClicked ( QListViewItem *, const QPoint &, int);
+	
+	private:
+		bool	initSearchEngine();
+		
+	private:
+		QComboBox 		*	m_searchQuery;
+		KQListView		*	m_searchList;
+		KQPopupMenu		* 	m_contextMenu;
+		
+		KCHMSearchEngine*	m_searchEngine;
 };
 
 #endif
