@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -263,7 +263,7 @@ QString KCHMViewWindow_QTextBrowser::decodeUrl( const QString &input )
 QPopupMenu * KCHMViewWindow_QTextBrowser::createPopupMenu( const QPoint & pos )
 {
 	KQPopupMenu * menu = getContextMenu( anchorAt( pos ), this );
-	menu->exec( mapToGlobal( pos ) );
+	menu->exec( mapToGlobal( contentsToViewport( pos ) ) );
 	return 0;
 }
 
