@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -136,4 +136,13 @@ public:
 #include <qbuttongroup.h>
 #include <qtooltip.h>
 
+
+class KCHMShowWaitCursor
+{
+	public:
+		KCHMShowWaitCursor() { QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) ); }
+		~KCHMShowWaitCursor() { QApplication::restoreOverrideCursor(); }
+};
+
+				 
 #endif /* KDE_QT_H */
