@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2005 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
+ *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
  *   Please do not use email address above for bug reports; see            *
  *   the README file                                                       *
  *                                                                         *
@@ -27,6 +27,9 @@
 
 #if defined (USE_KDE)
 	#include <kaboutdata.h>
+	#include <dcopclient.h>
+	
+	#include "kde/kchmdcopiface.h"
 #endif
 
 KCHMMainWindow * mainWindow;
@@ -40,10 +43,9 @@ int main( int argc, char ** argv )
     	{ "autotestmode", "Perform auto testing", 0 },
 		{ "shortautotestmode", "Perform short auto testing", 0 },
 		{ "+[chmfile]", "A CHM file to show", 0 },
-/*		{ "search <query>", I18N_NOOP("'--search <query>' specifies the search query to search, and activate the first entry if found"), 0 },
+		{ "search <query>", I18N_NOOP("'--search <query>' specifies the search query to search, and activate the first entry if found"), 0 },
 		{ "sindex <word>", I18N_NOOP("'--sindex <word>' specifies the word to find in index, and activate if found"), 0 },
-		{ "sbook <word>", I18N_NOOP("'--sbook <text>' specifies the word to find in bookmarks, and activate if found"), 0 },
-*/		KCmdLineLastOption
+		KCmdLineLastOption
  	};
 
 	KAboutData aboutdata ( "kchmviewer",
@@ -51,10 +53,10 @@ int main( int argc, char ** argv )
 				APP_VERSION,
 				I18N_NOOP("CHM file viewer"),
 				KAboutData::License_GPL,
-				"(c) 2005 George Yunaev, gyunaev@sourceforge.net",
+				"(c) 2004-2007 George Yunaev, gyunaev@ulduzsoft.com",
 				0,
-				"http://kchmviewer.sourceforge.net",
-				"gyunaev@sourceforge.net");
+				"http://www.kchmviewer.net",
+				"gyunaev@ulduzsoft.com");
 
 	KLocale::setMainCatalogue( "kchmviewer" );
 	KCmdLineArgs::init (argc, argv, &aboutdata);
@@ -68,8 +70,27 @@ int main( int argc, char ** argv )
 	appConfig.load();
 	app.installEventFilter( &gKeyEventFilter );
 	
+#if defined(USE_KDE)	
+	// DCOP stuff
+	KCHMDCOPIface iface;
+	
+	DCOPClient *client = kapp->dcopClient();
+	
+	if ( !client->attach() )
+		qWarning("DCOP attach failed");
+	
+	//QCString realAppId = client->registerAs( kapp->name() );
+	QCString realAppId = client->registerAs( "kchmviewer" );
+#endif
+						
 	mainWindow = new KCHMMainWindow();
 	mainWindow->show();
+	
+#if !defined(USE_KDE)
 	app.connect( &app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()) );
+#else
+	app.setMainWidget( mainWindow );
+#endif
+	
 	return app.exec();
 }
